@@ -5,7 +5,7 @@
 # Author:      Gordon Williams
 #
 # Created:     2003/11/03
-# RCS-ID:      $Id: plot.py,v 1.2 2005/03/17 08:01:56 eb Exp $
+# RCS-ID:      $Id: plot.py,v 1.4 2005/08/16 01:38:09 eb Exp $
 # Copyright:   (c) 2002
 # Licence:     Use as you wish.
 #-----------------------------------------------------------------------------
@@ -485,9 +485,8 @@ class PlotCanvas(wx.Window):
         # OnSize called to make sure the buffer is initialized.
         # This might result in OnSize getting called twice on some
         # platforms at initialization, but little harm done.
-        if wx.Platform != "__WXMAC__":
-            self.OnSize(None) # sets the initial size based on client size
-
+        self.OnSize(None) # sets the initial size based on client size
+                          # UNCONDITIONAL, needed to create self._Buffer
         
     # SaveFile
     def SaveFile(self, fileName= ''):
@@ -1210,7 +1209,8 @@ class PlotCanvas(wx.Window):
                 return lower, upper
         elif spec == 'auto':
             range = upper-lower
-            if range == 0.:
+            # if range == 0.:
+            if abs(range) < 1e-36:
                 return lower-0.5, upper+0.5
             log = _Numeric.log10(range)
             power = _Numeric.floor(log)
