@@ -20,7 +20,7 @@
 # Boston, MA 02111-1307, USA.
 # 
 
-from gnuradio import gr, gru
+from gnuradio import gr, gru, window
 from gnuradio.wxgui import stdgui
 import wx
 import gnuradio.wxgui.plot as plot
@@ -30,10 +30,12 @@ import threading
 import math    
 
 default_fftsink_size = (640,240)
+default_fft_rate = gr.prefs().get_long('wxgui', 'fft_rate', 15)
 
 class waterfall_sink_base(object):
     def __init__(self, input_is_real=False, baseband_freq=0,
-                 sample_rate=1, fft_size=512, fft_rate=20,
+                 sample_rate=1, fft_size=512,
+                 fft_rate=default_fft_rate,
                  average=False, avg_alpha=None, title=''):
 
         # initialize common attributes
@@ -66,8 +68,8 @@ class waterfall_sink_base(object):
 class waterfall_sink_f(gr.hier_block, waterfall_sink_base):
     def __init__(self, fg, parent, baseband_freq=0,
                  y_per_div=10, ref_level=50, sample_rate=1, fft_size=512,
-                 fft_rate=20, average=False, avg_alpha=None, title='',
-                 size=default_fftsink_size):
+                 fft_rate=default_fft_rate, average=False, avg_alpha=None,
+                 title='', size=default_fftsink_size):
 
         waterfall_sink_base.__init__(self, input_is_real=True, baseband_freq=baseband_freq,
                                sample_rate=sample_rate, fft_size=fft_size,
@@ -77,7 +79,8 @@ class waterfall_sink_f(gr.hier_block, waterfall_sink_base):
         s2p = gr.serial_to_parallel(gr.sizeof_float, fft_size)
         one_in_n = gr.keep_one_in_n(gr.sizeof_float * fft_size,
                                     max(1, int(sample_rate/fft_size/fft_rate)))
-        fft = gr.fft_vfc(fft_size, True, True)
+        mywindow = window.blackmanharris(fft_size)
+        fft = gr.fft_vfc(fft_size, True, mywindow)
         c2mag = gr.complex_to_mag(fft_size)
         self.avg = gr.single_pole_iir_filter_ff(1.0, fft_size)
         log = gr.nlog10_ff(20, fft_size, -20*math.log10(fft_size))
@@ -93,8 +96,8 @@ class waterfall_sink_f(gr.hier_block, waterfall_sink_base):
 class waterfall_sink_c(gr.hier_block, waterfall_sink_base):
     def __init__(self, fg, parent, baseband_freq=0,
                  y_per_div=10, ref_level=50, sample_rate=1, fft_size=512,
-                 fft_rate=20, average=False, avg_alpha=None, title='',
-                 size=default_fftsink_size):
+                 fft_rate=default_fft_rate, average=False, avg_alpha=None, 
+                 title='', size=default_fftsink_size):
 
         waterfall_sink_base.__init__(self, input_is_real=False, baseband_freq=baseband_freq,
                                      sample_rate=sample_rate, fft_size=fft_size,
@@ -104,7 +107,9 @@ class waterfall_sink_c(gr.hier_block, waterfall_sink_base):
         s2p = gr.serial_to_parallel(gr.sizeof_gr_complex, fft_size)
         one_in_n = gr.keep_one_in_n(gr.sizeof_gr_complex * fft_size,
                                     max(1, int(sample_rate/fft_size/fft_rate)))
-        fft = gr.fft_vcc(fft_size, True, True)
+
+        mywindow = window.blackmanharris(fft_size)
+        fft = gr.fft_vcc(fft_size, True, mywindow)
         c2mag = gr.complex_to_mag(fft_size)
         self.avg = gr.single_pole_iir_filter_ff(1.0, fft_size)
         log = gr.nlog10_ff(20, fft_size, -20*math.log10(fft_size))
